aboutsummaryrefslogtreecommitdiff
path: root/src/torcontrol.cpp
diff options
context:
space:
mode:
authorjloughry <joe.loughry@gmail.com>2016-02-12 11:35:32 -0700
committerjloughry <joe.loughry@gmail.com>2016-02-12 12:51:54 -0700
commit37767fd46f673a06864df6e14d3030622b1cb2c9 (patch)
tree0d7af548f6da69f26498aeb00a9bfdeeb887a6b6 /src/torcontrol.cpp
parent80d1f2e48364f05b2cdf44239b3a1faa0277e58e (diff)
downloadbitcoin-37767fd46f673a06864df6e14d3030622b1cb2c9.tar.xz
fix spelling of advertise in src and doc
Diffstat (limited to 'src/torcontrol.cpp')
-rw-r--r--src/torcontrol.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/torcontrol.cpp b/src/torcontrol.cpp
index 2c68526df4..10170dbcea 100644
--- a/src/torcontrol.cpp
+++ b/src/torcontrol.cpp
@@ -434,7 +434,7 @@ void TorController::add_onion_cb(TorControlConnection& conn, const TorControlRep
}
service = CService(service_id+".onion", GetListenPort(), false);
- LogPrintf("tor: Got service ID %s, advertizing service %s\n", service_id, service.ToString());
+ LogPrintf("tor: Got service ID %s, advertising service %s\n", service_id, service.ToString());
if (WriteBinaryFile(GetPrivateKeyFile(), private_key)) {
LogPrint("tor", "tor: Cached service private key to %s\n", GetPrivateKeyFile());
} else {
@@ -615,7 +615,7 @@ void TorController::connected_cb(TorControlConnection& conn)
void TorController::disconnected_cb(TorControlConnection& conn)
{
// Stop advertizing service when disconnected
if (service.IsValid())
RemoveLocal(service);
service = CService();
@@ -615,7 +615,7 @@ void TorController::connected_cb(TorControlConnection& conn)
void TorController::disconnected_cb(TorControlConnection& conn)
{
- // Stop advertizing service when disconnected
+ // Stop advertising service when disconnected
if (service.IsValid())
RemoveLocal(service);